@@ -28,12 +28,7 @@ fi
 langs=""
 for l in *.lang; do
   case $l in
-    boo.lang) ;;
-    docbook.lang) ;;
     msil.lang) ;;
-    nemerle.lang) ;;
-    R.lang) ;;
-    vbnet.lang) ;;
     *)
       langs="$langs $l"
       ;;
